@@ -1,5 +1,5 @@
 from __future__ import unicode_literals
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext_lazy as _
 
 
 def get_perm_name(model_name, perm_name):
